@@ -1,6 +1,7 @@
 #!/usr/bin/python2
 
 import os
+import subprocess
 import sys
 import gtk
 import gobject
@@ -137,7 +138,7 @@ def add_repository_via_cli(line, codename, forceYes, use_ppas):
         with open(file, "w") as text_file:
             text_file.write("%s\n" % deb_line)
             text_file.write("%s\n" % debsrc_line)
-    elif line.startswith("deb "):
+    elif line.startswith("deb ") | line.startswith("http"):
         with open("/etc/apt/sources.list.d/additional-repositories.list", "a") as text_file:
             text_file.write("%s\n" % expand_http_line(line, codename))
 
@@ -343,7 +344,7 @@ class Repository():
                                 else:
                                     name = subparts[-3].capitalize()
                             break
-                name = name.replace("Pearllinux", "Pearl Linux")
+                name = name.replace("Pearl", "Pearl")
                 name = name.replace("01", "Intel")
                 name = name.replace("Steampowered", "Steam")
             except:
@@ -644,7 +645,7 @@ class MirrorSelectionDialog(object):
             # We failed to identify the continent/country, let's show all mirrors
             self.visible_mirrors = mirrors
 
-        # Try to find the age of the Mint archive
+        # Try to find the age of the Pearl archive
         self.default_mirror_age = None
         self.default_mirror_date = None
         mirror_timestamp = self.get_url_last_modified("%s/db/version" % self.default_mirror)
@@ -766,7 +767,7 @@ class Application(object):
         self.selected_components = []
         if (len(self.optional_components) > 0):
             if os.path.exists("/etc/pearllinux/info"):
-                # This is Mint, we want to warn people about Romeo
+                # This is Pearl, we want to warn people about Romeo
                 warning_label = gtk.Label()
                 warning_label.set_alignment(0, 0.5)
                 warning_label.set_markup("<span font_style='oblique' font_stretch='ultracondensed'>%s</span>" % _("Warning: Unstable packages can introduce regressions and negatively impact your system. Please do not enable these options in Pearl Linux unless it was suggested by the development team."))
@@ -1021,7 +1022,7 @@ class Application(object):
         dialog.set_default_response(gtk.RESPONSE_OK)
         response = dialog.run()
         if response == gtk.RESPONSE_OK:
-            os.system("apt-key add %s" % dialog.get_filename())
+            subprocess.call(["apt-key", "add", dialog.get_filename()])
             self.load_keys()
             self.enable_reload_button()
         dialog.destroy()
@@ -1390,9 +1391,8 @@ class Application(object):
 
     def update_apt_cache(self, widget=None):
         self.disable_reload_button()
-        from subprocess import Popen, PIPE
         cmd = ["sudo", "/usr/sbin/synaptic", "--hide-main-window", "--update-at-startup", "--non-interactive"]
-        comnd = Popen(' '.join(cmd), shell=True)
+        comnd = subprocess.Popen(' '.join(cmd), shell=True)
         #returnCode = comnd.wait()
 
     def apply_official_sources(self, widget=None):
@@ -1496,8 +1496,12 @@ class Application(object):
             else:
                 url = mirror.url
             if url in selected_mirror:
-                if os.path.exists(FLAG_PATH % mirror.country_code.lower()):
-                    pearl_flag_path = FLAG_PATH % mirror.country_code.lower()
+                if mirror.country_code == "WD":
+                    flag = FLAG_PATH % '_united_nations'
+                else:
+                    flag = FLAG_PATH % mirror.country_code.lower()
+                if os.path.exists(flag):
+                    pearl_flag_path = flag
                     break
 
         for mirror in self.base_mirrors:
@@ -1539,6 +1543,18 @@ if __name__ == "__main__":
 
         (options, args) = parser.parse_args()
 
+        lsb_codename = commands.getoutput("lsb_release -sc")
+        config_dir = "/usr/share/pearlsources/%s" % lsb_codename
+        if not os.path.exists(config_dir):
+            print ("LSB codename: '%s'." % lsb_codename)
+            if os.path.exists("/etc/pearllinux/info"):
+                print ("Version of base-files: '%s'." % commands.getoutput("apt version base-files"))
+                print ("Your LSB codename isn't a valid Pearl Linux codename.")
+            else:
+                print ("This codename isn't currently supported.")
+            print ("Please check your LSB information with \"lsb_release -a\".")
+            sys.exit(1)
+
         if len(args) > 1 and (args[0] == "add-apt-repository"):
             ppa_line = args[1]
             lsb_codename = commands.getoutput("lsb_release -sc")
